==> igniteui-angular-charts-16.1.2-beta.0.tgz: package/esm5/lib/RateOfChangeAndMomentumIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { RateOfChangeAndMomentumIndicatorStrategy } from "./RateOfChangeAndMomentumIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
/**
 * @hidden
 */
var RateOfChangeAndMomentumIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(RateOfChangeAndMomentumIndicator, _super);
    function RateOfChangeAndMomentumIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    RateOfChangeAndMomentumIndicator.prototype.get_up = function () {
        return new RateOfChangeAndMomentumIndicatorStrategy();
    };
    Object.defineProperty(RateOfChangeAndMomentumIndicator.prototype, "up", {
        get: function () {
            return this.get_up();
        },
        enumerable: false,
        configurable: true
    });
    RateOfChangeAndMomentumIndicator.prototype.get_u2 = function () {
        return RateOfChangeAndMomentumIndicator.$;
    };
    Object.defineProperty(RateOfChangeAndMomentumIndicator.prototype, "u2", {
        get: function () {
            return this.get_u2();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(RateOfChangeAndMomentumIndicator.prototype, "va", {
        get: function () {
            return typeGetValue(this.c(RateOfChangeAndMomentumIndicator.vb));
        },
        set: function (a) {
            this.h(RateOfChangeAndMomentumIndicator.vb, a);
        },
        enumerable: false,
        configurable: true
    });
    RateOfChangeAndMomentumIndicator.prototype.uv = function () {
        return this.va;
    };
    RateOfChangeAndMomentumIndicator.prototype.u4 = function (a) {
        this.va = a;
    };
    RateOfChangeAndMomentumIndicator.$t = markType(RateOfChangeAndMomentumIndicator, 'RateOfChangeAndMomentumIndicator', StrategyBasedIndicator.$);
    RateOfChangeAndMomentumIndicator.vb = StrategyBasedIndicator.u7(14, RateOfChangeAndMomentumIndicator.$);
    return RateOfChangeAndMomentumIndicator;
}(StrategyBasedIndicator));
export { RateOfChangeAndMomentumIndicator };

==> igniteui-angular-charts-17.2.0-beta.0.tgz: package/esm5/lib/RateOfChangeAndMomentumIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { RateOfChangeAndMomentumIndicatorStrategy } from "./RateOfChangeAndMomentumIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
/**
 * @hidden
 */
var RateOfChangeAndMomentumIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(RateOfChangeAndMomentumIndicator, _super);
    function RateOfChangeAndMomentumIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    RateOfChangeAndMomentumIndicator.prototype.get_yy = function () {
        return new RateOfChangeAndMomentumIndicatorStrategy();
    };
    Object.defineProperty(RateOfChangeAndMomentumIndicator.prototype, "yy", {
        get: function () {
            return this.get_yy();
        },
        enumerable: false,
        configurable: true
    });
    RateOfChangeAndMomentumIndicator.prototype.get_zb = function () {
        return RateOfChangeAndMomentumIndicator.$;
    };
    Object.defineProperty(RateOfChangeAndMomentumIndicator.prototype, "zb", {
        get: function () {
            return this.get_zb();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(RateOfChangeAndMomentumIndicator.prototype, "zj", {
        get: function () {
            return typeGetValue(this.c(RateOfChangeAndMomentumIndicator.zk));
        },
        set: function (a) {
            this.h(RateOfChangeAndMomentumIndicator.zk, a);
        },
        enumerable: false,
        configurable: true
    });
    RateOfChangeAndMomentumIndicator.prototype.y4 = function () {
        return this.zj;
    };
    RateOfChangeAndMomentumIndicator.prototype.zd = function (a) {
        this.zj = a;
    };
    RateOfChangeAndMomentumIndicator.$t = markType(RateOfChangeAndMomentumIndicator, 'RateOfChangeAndMomentumIndicator', StrategyBasedIndicator.$);
    RateOfChangeAndMomentumIndicator.zk = StrategyBasedIndicator.zg(14, RateOfChangeAndMomentumIndicator.$);
    return RateOfChangeAndMomentumIndicator;
}(StrategyBasedIndicator));
export { RateOfChangeAndMomentumIndicator };
